.mystyle {
    font-size: 11pt;
    font-family: Arial;
    border-collapse: collapse;
    border: 1px solid silver;

}

.mystyle td, th {
    padding: 5px;
}

.mystyle tr:nth-child(even) {
    background: lightcyan;
}

.mystyle tr:hover {
    background: silver;
    cursor: pointer;
}

.minus{
    color: lightcoral;
}
.plus{
    color: lightseagreen;
}